@@ -13,7 +13,7 @@
 
 from oslo_log import log as logging
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from sahara_dashboard.api import sahara as saharaclient
 
 from horizon import exceptions
@@ -100,6 +100,11 @@ class GeneralTab(tabs.Tab):
                                  "base_image": base_image,
                                  "cluster_template": cluster_template,
                                  "network": net_name})
+
+            if saharaclient.VERSIONS.active == '2':
+                cluster_info["cluster"].hadoop_version = (
+                    cluster_info["cluster"].plugin_version
+                )
         except Exception as e:
             LOG.error("Unable to fetch cluster details: %s" % str(e))
 
