@@ -13,8 +13,8 @@
 
 from django import http
 from django.template import defaultfilters as filters
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ngettext_lazy
 
 from horizon import tables
 from horizon.tabs import base as tabs_base
@@ -95,7 +95,7 @@ class ExportTemplate(tables.Action):
 class DeleteTemplate(tables.DeleteAction):
     @staticmethod
     def action_present(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Delete Template",
             u"Delete Templates",
             count
@@ -103,7 +103,7 @@ class DeleteTemplate(tables.DeleteAction):
 
     @staticmethod
     def action_past(count):
-        return ungettext_lazy(
+        return ngettext_lazy(
             u"Deleted Template",
             u"Deleted Templates",
             count
@@ -147,7 +147,11 @@ class NodegroupTemplatesTable(sahara_table.SaharaPaginateTabbedTable):
         link="horizon:project:data_processing.clusters:details")
     plugin_name = tables.Column("plugin_name",
                                 verbose_name=_("Plugin"))
-    hadoop_version = tables.Column("hadoop_version",
+    if saharaclient.VERSIONS.active == '2':
+        version_attr = "plugin_version"
+    else:
+        version_attr = "hadoop_version"
+    hadoop_version = tables.Column(version_attr,
                                    verbose_name=_("Version"))
     node_processes = tables.Column("node_processes",
                                    verbose_name=_("Node Processes"),
