@@ -13,7 +13,7 @@
 from horizon.test.settings import *  # noqa
 from openstack_dashboard.test.settings import *  # noqa
 
-INSTALLED_APPS = list(INSTALLED_APPS)
+INSTALLED_APPS = list(INSTALLED_APPS)  # noqa: F405
 INSTALLED_APPS.append('sahara_dashboard.content.data_processing.clusters')
 INSTALLED_APPS.append('sahara_dashboard.content.data_processing.jobs')
 INSTALLED_APPS.append('sahara_dashboard.content.data_processing.data_plugins')
